#
# spec file for package goxel
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           goxel
Version:        0.15.1
Release:        1.4
Summary:        Voxel graphics editor
License:        GPL-3.0-only
Group:          Productivity/Graphics/3D Editors
URL:            https://goxel.xyz/
Source:         https://github.com/guillaumechereau/goxel/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  scons
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(glfw3)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(zlib)

%description
Goxel is an open source voxel graphics editor. Voxels are 3D images formed
of cubic elements.

%prep
%autosetup -p1

%build
# Manually set build flag as Leap 15.2 does not support %%{set_build_flags} macro unlike TW.
CFLAGS='-O2 -D_FORTIFY_SOURCE=2 -fstack-protector-strong -funwind-tables -fasynchronous-unwind-tables -fstack-clash-protection -Werror=return-type -flto=auto'
export CFLAGS
CXXFLAGS='-O2 -D_FORTIFY_SOURCE=2 -fstack-protector-strong -funwind-tables -fasynchronous-unwind-tables -fstack-clash-protection -Werror=return-type -flto=auto'
export CXXFLAGS
FFLAGS='-O2 -D_FORTIFY_SOURCE=2 -fstack-protector-strong -funwind-tables -fasynchronous-unwind-tables -fstack-clash-protection -Werror=return-type -flto=auto '
export FFLAGS
FCFLAGS='-O2 -D_FORTIFY_SOURCE=2 -fstack-protector-strong -funwind-tables -fasynchronous-unwind-tables -fstack-clash-protection -Werror=return-type -flto=auto '
export FCFLAGS
LDFLAGS=-flto=auto
export LDFLAGS
scons mode=release

%install
%make_install PREFIX=%{_prefix}

sed -i 's/\${SNAP}\/icon.png/%{name}/g' %{buildroot}%{_datadir}/applications/%{name}.desktop

%files
%license COPYING
%doc README.md
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/metainfo/io.github.guillaumechereau.Goxel.metainfo.xml

%changelog
* Sat Oct 12 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to 0.15.1:
  * Improved extrude tool, with manual delta input.
  * Improved help messages.
  * Added support to emulate middle mouse button with Alt.
  * Allow to configure the navigation mouse buttons.
* Sun Jul 28 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to 0.15.0:
  * Improved the selection tool: the selection mask is now
    automatically updated when we move the selection box, and the
    move tool automatically applies to the selection mask.
  * Improved the gizmos to move the selection box, so that we can
    move or grow without having to select the mode in the UI.
  * Add support for adding and subtracting the selection box.
  * Added a new 'edit' panel for the selection mask operations.
* Sun May 19 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to 0.14.0:
  * Improved the general UI of the app, with a more modern style.
  * Allow to detach UI panels.
  * Improved glTF export.
  * Improved files opening (add recent file list, remember last opened dir).
  * Add layer origin control.
* Wed Jan 10 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to 0.13.0:
  * Some fixes for glTF export.
  * Added shortcuts for Add/Sub/Paint.
  * Allow to simplify exported glTF.
- dropped patch fix_security_issue_in_quickjs.patch as already included in upstream
* Mon Nov  6 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Thu Aug 24 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to 0.12.0
  * Added basic support for Minetest file format import.
  * Added a new tool to select from a 2d rectangle.
  * Fixed issues with high density screens.
  * Added some (very basic) support for scripting.
  The biggest new feature is probably the scripting support. For the moment it is very limited, see the example in data/scripts/test.js. If you would like to make your own scripts but some features are missing (and they will), please open an issue about it.
- Added patch fix_security_issue_in_quickjs.patch to address potential security issue
* Mon Dec  5 2022 Tuukka Pasanen <tuukka.pasanen@ilmi.fi>
- Update to 0.11.0
  * Improve vlx import.
  * Add support for plane at non 90 deg angles.
  * Add basic support for selection mask, so that we can add or subtract from the current selection.
* Mon Dec 13 2021 Tuukka Pasanen <tuukka.pasanen@ilmi.fi>
- Update to 0.10.8
  * Only minor changes and bug fix.
* Sun Feb 21 2021 Matthias Mailänder <mailaender@opensuse.org>
- Install upstream appdata and desktop file.
- Avoid non-standard icon sizes
- Fix non-standard-group Unspecified
- Update URL
* Fri Dec 25 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Update to 0.10.7
  * Minor release with mostly improvements to the glTF export.
  * Sort the file list to make package build reproducible (boo#1041090)
* Tue Oct 27 2020 andy great <andythe_great@pm.me>
- Remove %%{set_build_flags} and manually set build flag because
  Leap 15.2 does not support this macro.
* Mon Oct 19 2020 andy great <andythe_great@pm.me>
- Initial package release.
